graphium.ipu
====================
Code for adapting to run on IPU

=== "Contents"

    * [IPU Dataloader](#ipu-dataloader)
    * [IPU Losses](#ipu-losses)
    * [IPU Metrics](#ipu-metrics)
    * [IPU Simple Lightning](#ipu-simple-lightning)
    * [IPU Utils](#ipu-utils)
    * [IPU Wrapper](#ipu-wrapper)
    * [To Dense Batch](#to-dense-batch)

## IPU Dataloader
------------
::: graphium.ipu.ipu_dataloader


## IPU Losses
------------
::: graphium.ipu.ipu_losses


## IPU Metrics
------------
::: graphium.ipu.ipu_metrics


## IPU Simple Lightning
------------
::: graphium.ipu.ipu_simple_lightning


## IPU Utils
------------
::: graphium.ipu.ipu_utils


## IPU Wrapper
------------
::: graphium.ipu.ipu_wrapper


## To Dense Batch
------------
::: graphium.ipu.to_dense_batch

